# Security Policy

## Supported Versions

| Version | Supported |
|---------|-----------|
| 0.1.x   | Yes       |

## Reporting a Vulnerability

If you discover a security vulnerability, please report it responsibly.

**Do not open a public issue.** Instead, use
[GitHub's private vulnerability reporting](https://github.com/arielarevalo/opensage-acp/security/advisories/new).

You should receive a response within 72 hours. The report will be investigated
and a fix issued as soon as possible.
